# login-auth-tui

[![Changelog](https://img.shields.io/github/v/release/nwgh/login-auth-tui?include_prereleases&label=changelog)](https://github.com/nwgh/login-auth-tui/releases)
[![Tests](https://github.com/nwgh/login-auth-tui/actions/workflows/test.yml/badge.svg)](https://github.com/nwgh/login-auth-tui/actions/workflows/test.yml)
[![License](https://img.shields.io/badge/license-CC0%201.0-blue.svg)](https://github.com/nwgh/login-auth-tui/blob/master/LICENSE)

TUI for login-auth stuff

## Installation

Install this tool from the releases page

## Usage

For help, run:
```bash
login-auth-tui --help
```

## Development

To contribute to this tool, first install `uv`. See [the uv documentation](http
s://docs.astral.sh/uv/getting-started/installation/) for how.

Next, checkout the code
```bash
git clone https://github.com/nwgh/login-auth-tui
```

Then create a new virtual environment and sync the dependencies:
```bash
cd login-auth-tui
uv sync
```

To run the tests:
```bash
uv run python -m pytest
```
